OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "書籤",
    "You bookmarked \"%s\"" : "您已建立書籤 \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s 建立書籤 \"%2$s\"",
    "Someone bookmarked \"%s\"" : "有人建立書籤 \"%s\"",
    "You deleted \"%s\"" : "您已刪除 \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s 已刪除 \"%2$s\"",
    "Someone deleted \"%s\"" : "有人刪除 \"%s\"",
    "You created folder \"%s\"" : "您已建立資料夾 \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s 已建立資料夾 \"%2$s\"",
    "Someone created folder \"%s\"" : "有人建立資料夾 \"%s\"",
    "You moved folder \"%s\"" : "您已移動資料夾 \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s 已移動資料夾 \"%2$s\"",
    "Someone moved folder \"%s\"" : "有人移動資料夾 \"%s\"",
    "You deleted folder \"%s\"" : "您已刪除資料夾 \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s 已刪除資料夾 \"%2$s\"",
    "Someone deleted folder \"%s\"" : "有人刪除資料夾 \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "您已與 %2$s 共用 \"%1$s\" ",
    "You shared folder \"%s\" with someone" : "您已與某人共用 \"%s\"",
    "%1$s shared folder \"%2$s\" with you" : "%1$s 已共用資料夾 \"%2$s\" 給您",
    "Someone shared folder \"%s\" with you" : "有人共用資料夾 \"%s\" 給您",
    "You unshared folder \"%1$s\" with %2$s" : "您已取消與 %2$s 共用的資料夾 \"%1$s\"",
    "You unshared folder \"%s\" with someone" : "您已取消與某人共用的資料夾 \"%s\"",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s 已取消與您共用的資料夾 \"%2$s\" ",
    "Someone unshared folder \"%s\" with you" : "某人已取消與你共用的資料夾 \"%s\"",
    "No file provided for import" : "無匯入檔案",
    "Failed to upload file" : "上傳檔案失敗",
    "Unsupported file type for import: " : "匯入不支援的檔案格式：",
    "Bookmarks shared by %s" : "由 %s 共用的書籤",
    "Frequent bookmarks" : "常用書籤",
    "Recent bookmarks" : "最近使用的書籤",
    "Bookmark" : "書籤",
    "Bookmark deleted" : "書籤已刪除",
    "Bookmark created" : "書籤已建立",
    "Bookmark moved" : "書籤已移動",
    "Bookmark updated" : "書籤已更新",
    "Create bookmark" : "已建立書籤",
    "Takes a link and adds it to your collection of bookmarks." : "將連結添加到您的書籤收藏。",
    "Bookmarks Backups" : "書籤備份",
    "Collect and manage bookmarks, synced with all your devices" : "收集和管理書籤．並與所有裝置同步",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 將書籤分類整理到資料夾中\n- 🏷 添加標籤和個人註解\n- ☠ 找出失效連結及重複項目\n- 📲 與所有瀏覽器及裝置同步\n- 📔 存儲連結已封的存版本，以防它們被刪除\n- 🔍 對網站內容進行全文搜索\n- 👪 與其他用戶、群組和團隊分享書籤，並提供公開連結\n- ⚛ 為您的書籤集合產生 RSS 訂閱源\n- 📈 統計您存取各個連結的頻率\n- 🔒 自動備份您的書籤集合\n- 💼 內建儀表板小組件以顯示常用及最近的連結\n\n技術要求:\n - PHP 擴充套件:\n   - intl: *\n   - mbstring: *\n - 使用 MySQL 時，需使用至少 v8.0 版本",
    "Do you really want to delete this bookmark?" : "您確定要刪除此書籤嗎？",
    "Link copied to clipboard" : "已複製連結至剪貼板",
    "Enter new title" : "輸入新的標題",
    "Select bookmark" : "選擇書籤",
    "You have never clicked this link" : "您從未點擊過此連結",
    "You have clicked this link {count} times" : "您已點擊過此連結 {count} 次",
    "Details" : "細節",
    "Rename" : "重新命名",
    "Copy link" : "複製連結",
    "Move" : "移動",
    "Add to folders" : "添加到資料夾",
    "Put bookmark into trash bin" : "將書籤放到回收桶中",
    "Restore bookmark" : "還原書籤",
    "Delete bookmark permanently" : "永久刪除書籤",
    "Content pending" : "內容待定",
    "This content is being downloaded for offline use. Please check back later." : "正在下載此內容以供離線使用。請稍後再檢查。",
    "Bookmarked {time} ago" : "{time} 前加入書籤",
    "Bookmarked on {date}" : "於 {date} 加入書籤",
    "These are your deleted items. Items will be deleted permanently after two months." : "這是您已刪除的項目。項目將在兩個月後永久刪除。",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "網絡上的檔案（如照片或 PDF）的書籤將自動保存到您的 Nextcloud 檔案中，因此即使連結離線，您也仍然可以找到它們。",
    "Searching in the current folder only." : "僅在目前資料夾中搜尋。",
    "Repeat search in all folders" : "在所有資料夾中重複搜尋",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "已加入書籤的連結會定期檢查，無法存取的連結就會在此列出。",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "您可以與其他人分享書籤資料夾。此處列出了與您分享的所有資料夾。",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "一個書籤可以同時位於多個文件夾中。 更新它將更新所有副本。 為方便起見，此處列出了所有重複的書籤。",
    "Selected {folders} folders and {bookmarks} bookmarks" : "所選 {folders} 資料夾 和 {bookmarks} 書籤",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["已選擇 %n 個書籤"],
    "_Selected %n folder_::_Selected %n folders_" : ["已選擇 %n 個資料夾"],
    "Do you really want to delete these items?" : "您確定要刪除這些項目嗎？",
    "Open all selected" : "開啟所有選擇對象",
    "Move selection" : "移動選擇",
    "Edit tags of selection" : "編輯所選項目的標籤",
    "Delete selection" : "刪除所選",
    "Select all" : "全選",
    "Cancel selection" : "取消選擇",
    "Sort by created date" : "按創建日期排序",
    "Sort by last modified" : "按修改日期排序",
    "Sort by title" : "按標題排序",
    "Sort by click count" : "按點擊次數排序",
    "Sort by manual order" : "手動排序",
    "Sort by URL" : "依 URL 排序",
    "RSS feed copied" : "RSS feed 已複製",
    "Trash Bin" : "回收桶",
    "Go back" : "返回",
    "Share folder" : "分享資料夾",
    "Open folder details" : "公開資料夾細節",
    "Select one or more tags" : "選擇一個或是多個標籤",
    "New" : "新增",
    "New bookmark" : "新增書籤",
    "New folder" : "新增資料夾",
    "Change to grid view" : "切換至網格檢視",
    "Change to list view" : "切換到列表視圖",
    "Copy RSS Feed of current view" : "複製目前視圖的RSS Feed",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS feed 需要使用您的 Nextcloud 身份驗證進行驗證",
    "Search" : "搜尋",
    "Empty trash bin" : "清空回收桶",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["將 %n 書籤添加到新資料夾"],
    "Enter a link" : "輸入連結",
    "Enter a title" : "輸入標題",
    "No bookmarks found" : "未發現書籤",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} 資料夾和 {bookmarks} 書籤",
    "_%n bookmark_::_%n bookmarks_" : ["%n 書籤"],
    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
    "Welcome to Bookmarks" : "歡迎來到 Bookmarks",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "此應用程式允許您管理網絡上您最喜歡的地方的連結。將您的書籤分類到資料夾中，用標籤標記它們並與他人分享！該應用程式將定期檢查您所有連結的空閒時間並顯示不可用的連結。如果您在網絡上添加指向檔案的連結，該檔案將自動下載到您的 Nextcloud Files 中。您還可以導入從其他服務導出的書籤，或直接將所有瀏覽器中的書籤與此應用程式同步。",
    "Add a bookmark" : "新增書籤",
    "Import bookmarks" : "匯入書籤",
    "Sync with your browser" : "與瀏覽器同步",
    "Do you really want to permanently delete this folder?" : "您真的想要永久刪除此資料夾嗎？",
    "Select folder" : "選擇資料夾",
    "Enter folder title" : "輸入資料夾標題",
    "Shared by {user}" : "由 {user} 分享",
    "Rename folder" : "重新命名資料夾",
    "Move folder" : "移動資料夾",
    "Put folder into trashbin" : "將資料夾放到回收桶中",
    "Restore folder" : "還原資料夾",
    "Delete folder permanently" : "永久刪除資料夾",
    "Choose folder" : "選擇資料夾",
    "Submit" : "遞交",
    "Cancel" : "取消",
    "Deleting bookmarks" : "刪除書籤",
    "Deleting selection" : "刪除選擇",
    "Importing bookmarks" : "匯入書籤",
    "Moving selection" : "移動選擇",
    "Adding selection to folders" : "將所選項目添加到資料夾",
    "Emptying trashbin" : "清空回收桶",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["正在移動%n資料夾和一些書籤"],
    "_Moving %n folder_::_Moving %n folders_" : ["移動%n個資料夾"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["正在移動%n個書籤"],
    "All bookmarks" : "所有書籤",
    "Recent" : "最新",
    "Shared with you" : "與您分享",
    "Files" : "檔案",
    "Duplicates" : "複本",
    "Broken links" : "連結斷開",
    "New tag" : "新標籤",
    "Search tags" : "搜索標籤",
    "Delete" : "刪除",
    "Untagged" : "未標記",
    "{used} bookmarks of {available} available" : "{available} 個可用書籤中的 {used} 個。",
    "Bookmarks Settings" : "書籤設定",
    "No bookmarked files" : "沒有已加書籤的檔案",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "照片或PDF等檔案的書籤將自動保存到您的Nextcloud檔案中，因此即使連結脫機，您仍然可以找到它們。",
    "Nothing found" : "沒有找到任何內容",
    "Your search yielded no results in the current folder." : "您的搜尋在目前資料夾中沒有任何結果。",
    "No broken links" : "沒有失效的連結",
    "No shared folders" : "沒有已分享的資料夾",
    "No duplicated bookmarks" : "沒有書籤複本",
    "No deleted bookmarks" : "沒有已刪除的書籤",
    "You haven't deleted anything yet." : "您尚未刪除任何東西。",
    "No bookmarks here" : "無書籤",
    "Add bookmarks manually or import bookmarks from a HTML file." : "手動添加書籤或從 HTML 檔案導入書籤。",
    "Archive path" : "封存路徑",
    "Backup path" : "備份路徑",
    "Please select \"Add to home screen\" in your browser menu" : "請在瀏覽器菜單中選擇“添加到主螢幕”",
    "Bookmarks settings" : "書籤設定",
    "Import/Export" : "導入/導出",
    "Export bookmarks" : "導出書籤",
    "Auto-archiving" : "自動封存",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "書籤應用程式可以自動封存您加入書籤的網路內容",
    "Enable archiving" : "啟用封存",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "輸入應該存儲書籤檔案的資料夾的路徑",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "目前您的管理員已停用此應用程式的網絡存取，這就是目前停用自動存檔的原因。",
    "Auto-Backup" : "自動備份",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "書籤應用程式可以每天自動備份您的書籤，以防止跨裝置同步書籤時遺失資料。",
    "Enable backups" : "啟用備份",
    "Enter the path of a folder in your Files where backups will be stored." : "輸入在您「檔案」中要儲存備份的資料夾路徑。",
    "Context Chat integration" : "情境聊天整合",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "書籤應用程式可自動將書籤網站的文字內容提供給情境聊天，以便根據這些內容發問並獲得答案。只有啟用自動封存時才能使用此功能。",
    "Context chat is currently not installed, but is required for this feature." : "目前尚未安裝情境聊天，但此功能需要情境聊天。",
    "Enable Context Chat integration" : "啟用情境聊天整合",
    "Client apps" : "客戶端 apps",
    "Also check out the collection of client apps that integrate with this app: " : "還請檢查與此應用程序集成的客戶端應用程序的集合：",
    "Install web app" : "安裝 web 應用程式",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "您可以在設備主螢幕上安裝此應用程序以快速訪問手機上的書籤。如果您不喜歡它，您可以輕鬆地再次從主螢幕中刪除該應用程式。",
    "Install on home screen" : "在主螢幕上安裝",
    "Bookmarklet" : "書籤",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "將此拖拉到您瀏覽器書籤中且點擊它以快速為網頁添加書籤。",
    "Add to {instanceName}" : "加到 {instanceName}",
    "Need help?" : "需要協助嗎？",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "若您在使用此書籤應用程式時遇到問題或有任何關於改進的想法，請隨時按此處與我們聯絡。",
    "Support this project" : "支援此專案",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "我開發呢個「書籤」App 嘅工作係靠自願訂閱模式來維持嘅。如果你覺得我嘅工作有價值，就請支持下我嘅工作。此外，你都可以考慮喺 Nextcloud App 商店裏面，幫呢個 App 寫一個評價。多謝你 💙",
    "Created {time} ago" : "在 {time} 前創建",
    "Created on {date}" : "創建於 {date} ",
    "(Empty title)" : "（空的標題）",
    "Title" : "標題",
    "Link" : "連結",
    "Untitled folder" : "未命名資料夾",
    "Root folder" : "根資料夾",
    "Tags" : "標籤",
    "Select tags and create new ones" : "選擇標籤或創建新標籤",
    "Notes" : "註釋",
    "Notes for this bookmark …" : "此書籤的註釋...",
    "Archived file" : "已封存檔案",
    "Open file" : "開啟檔案",
    "Download file" : "下載檔案",
    "Open file location" : "開啟檔案位置",
    "Link copied" : "連結已複製",
    "Owner" : "擁有者",
    "Sharing" : "分享",
    "Select a user or group" : "選擇用戶或群組",
    "Share link" : "分享連結",
    "Reading allowed" : "允許讀取",
    "Copy RSS feed" : "複製 RSS feed",
    "Delete link" : "刪除連結",
    "Create public link" : "建立公共連結",
    "Resharing allowed" : "允許轉貼分享",
    "Editing allowed" : "允許編輯",
    "Allow editing" : "允許編輯",
    "Allow resharing" : "允許轉貼分享",
    "Remove share" : "移除分享",
    "Failed to save settings" : "設定儲存失敗",
    "Failed to load settings" : "載入設定失敗",
    "Privacy" : "私隱",
    "The app will try to access web pages that you add to automatically add information about them." : "該應用程式將嘗試存取您新增的網頁以自動新增關於它們的資訊。",
    "Enable accessing and collecting information from the web pages you add" : "從您增加的網頁啟用存取及收集資訊",
    "Performance" : "效能",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "在具有大量用戶的安裝中，限制每個帳戶的書籤數量可能很有用。",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "每個帳號可以允許的書籤最大數量。（0是無限制; 預設是無限制）",
    "Previews" : "預覽",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "為了顯示您加入書籤的網站的真實螢幕截圖，該應用程式會使用第三方服務來生成預覽。",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "您可以免費在 screeenly。com 註冊或是設定您自己的伺服器。",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API key",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Generic screenshot API" : "一般螢幕截圖 API",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "向任何螢幕截圖 API 提供者註冊，並將 API URL 放在下面。使用變數 {url} 作為螢幕截圖 URL 的佔位字串。 API 必須僅直接傳回影像。",
    "Generic API URL" : "一般 API URL",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "只要在您的伺服器上安裝 Sindre Sorhus 開發的 Pageres CLI，書籤應用程式就會找到它。您仍然可以新增額外的 ENV 變數以提供給 pageres，例如在佔位字串中所示：",
    "Pageres ENV variables" : "Pageres ENV 變數",
    "This URL is already bookmarked! Overwrite?" : "此連結已存在，是否複寫？",
    "Enter bookmark title" : "輸入書籤標題",
    "Enter bookmark URL" : "輸入書籤URL",
    "Folder" : "資料夾",
    "Root Folder" : "根資料夾",
    "Save" : "儲存",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "默認情況下，網絡存取處於停用狀態。轉到書籤應用程式的管理員設置，以啟用獲取預覽和網站圖標的功能。",
    "What's new?" : "有什麼新鮮事？",
    "Leave a rating on the Nextcloud App Store" : "在 Nextcloud App Store 留下評分",
    "What" : "甚麼",
    "Failed to count unavailable bookmarks" : "無法點算不可用的書籤",
    "Failed to count archived bookmarks" : "無法點算已封存的書籤",
    "Failed to count deleted bookmarks" : "無法統計已刪除的書籤數量",
    "Failed to count duplicated bookmarks" : "無法點算書籤複本",
    "Failed to count bookmarks" : "無法計算書籤數量",
    "Failed to load bookmark" : "載入書籤失敗",
    "Failed to find existing bookmark" : "尋找現存的書籤失敗",
    "Failed to create bookmark" : "建立書籤失敗",
    "Failed to save bookmark" : "儲存書籤失敗",
    "Failed to move bookmark" : "移動書籤失敗",
    "Failed to copy bookmark" : "無法複製書籤",
    "Failed to delete bookmark" : "刪除書籤失敗",
    "Failed to restore bookmark" : "無法還原書籤",
    "Import successful" : "導入成功",
    "Failed to rename tag" : "重新命名標籤失敗",
    "Failed to load tags" : "載入標記失敗",
    "Failed to load folders" : "載入資料夾失敗",
    "Failed to load deleted folders" : "載入已刪除資料夾失敗",
    "Failed to load deleted bookmarks" : "無法加載已刪除書籤",
    "Failed to delete folder" : "刪除資料夾失敗",
    "Failed to move folder" : "無法移動資料夾",
    "Failed to restore folder" : "無法還原資料夾",
    "Failed to create folder" : "建立資料夾失敗",
    "Failed to load children order" : "無法加載子排序",
    "Failed to move parts of selection" : "無法移動部分選擇",
    "Failed to copy parts of selection" : "無法複製部分選擇",
    "Failed to delete parts of selection" : "無法刪除部分選擇",
    "Failed to tag parts of selection" : "無法標籤部分選擇",
    "Failed to fetch bookmarks." : "擷取書籤失敗",
    "Failed to store setting" : "儲存設定失敗",
    "Failed to load setting {key}" : "載入設定失敗 {key}",
    "Failed to create share for folder {folderId}" : "無法為資料夾 {folderId} 創建分享",
    "Failed to update share {shareId}" : "更新分享失敗 {shareId}",
    "Failed to delete share {shareId}" : "無法刪除分享 {shareId}",
    "Failed to create public link for folder {folderId}" : "無法為資料夾 {folderId} 創建公共連結",
    "Failed to delete public link for folder {folderId}" : "無法刪除資料夾 {folderId} 的公共連結",
    "Failed to permanently delete parts of trash bin" : "無法永久刪除部分回收桶",
    "Create bookmarks for mentioned links" : "為提到的連結建立書籤",
    "No links found in this message" : "此訊息中找不到連結",
    "Bookmarks feed" : "Bookmarks feed"
},
"nplurals=1; plural=0;");
